netapp_ontap.models.common_data_source API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.common_data_source`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class CommonDataSourceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the CommonDataSource object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `cluster: Cluster GET POST PATCH`

    The cluster field of the common_data_source.

  `is_remote: bool GET POST PATCH`

    The property that specifies if the data source is local or remote. Required in a POST request.

  `name: str GET POST PATCH`

    The name of the volume or bucket, whether it is local or remote storage.

    Example: workspace

  `peer_svm: Svm GET POST PATCH`

    The peer_svm field of the common_data_source.

  `svm: Svm GET POST PATCH`

    The svm field of the common_data_source.

  `type: str GET POST PATCH`

    The type field of the common_data_source.

  `uuid: str GET POST PATCH`

    The unique identifier of a volume or bucket, whether it is local or remote storage. Required in a POST request.

    Example: 4ea7a442-86d1-11e0-ae1c-123478563412